from typing import List, Optional, Union, Dict, Any
from sqlalchemy.orm import Session

from app.models.artist import Artist
from app.schemas.artist import ArtistCreate, ArtistUpdate


def get_artist(db: Session, artist_id: int) -> Optional[Artist]:
    return db.query(Artist).filter(Artist.id == artist_id).first()


def get_artist_by_name(db: Session, name: str) -> Optional[Artist]:
    return db.query(Artist).filter(Artist.name == name).first()


def get_artists(
    db: Session, skip: int = 0, limit: int = 100, search: Optional[str] = None
) -> List[Artist]:
    query = db.query(Artist)
    if search:
        query = query.filter(Artist.name.ilike(f"%{search}%"))
    return query.offset(skip).limit(limit).all()


def create_artist(db: Session, obj_in: ArtistCreate) -> Artist:
    db_obj = Artist(
        name=obj_in.name,
        bio=obj_in.bio,
        image_path=obj_in.image_path,
    )
    db.add(db_obj)
    db.commit()
    db.refresh(db_obj)
    return db_obj


def update_artist(
    db: Session, *, db_obj: Artist, obj_in: Union[ArtistUpdate, Dict[str, Any]]
) -> Artist:
    if isinstance(obj_in, dict):
        update_data = obj_in
    else:
        update_data = obj_in.dict(exclude_unset=True)
    for field in update_data:
        if hasattr(db_obj, field):
            setattr(db_obj, field, update_data[field])
    db.add(db_obj)
    db.commit()
    db.refresh(db_obj)
    return db_obj


def delete_artist(db: Session, *, id: int) -> None:
    artist = db.query(Artist).get(id)
    if artist:
        db.delete(artist)
        db.commit()